@@ -65,8 +65,6 @@ class Worksheet : public QGraphicsScene
     bool showExpressionIds();
     bool animationsEnabled();
 
-    void print(QPrinter* printer);
-
     bool isPrinting();
 
     void setViewSize(qreal w, qreal h, qreal s, bool forceUpdate = false);
@@ -134,6 +132,8 @@ class Worksheet : public QGraphicsScene
     void updateLayout();
     void updateEntrySize(WorksheetEntry* entry);
 
+    void print(QPrinter* printer);
+
     void focusEntry(WorksheetEntry * entry);
 
     void evaluate();
@@ -155,8 +155,12 @@ class Worksheet : public QGraphicsScene
     QDomDocument toXML(KZip* archive=0);
 
     void save(const QString& filename);
+    void save(QIODevice* device);
+    QByteArray saveToByteArray();
     void savePlain(const QString& filename);
     void saveLatex(const QString& filename);
+    void load(QIODevice* device);
+    void load(QByteArray* data);
     void load(const QString& filename);
 
     void gotResult(Cantor::Expression* expr=0);
